@@ -13,9 +13,19 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from oslo_config import cfg
+from oslo_policy import opts
 from oslo_policy import policy
 from pecan import hooks
 
+from aodh.api import policies
+
+# TODO(gmann): Remove setting the default value of config policy_file
+# once oslo_policy change the default value to 'policy.yaml'.
+# https://github.com/openstack/oslo.policy/blob/a626ad12fe5a3abd49d70e3e5b95589d279ab578/oslo_policy/opts.py#L49
+DEFAULT_POLICY_FILE = 'policy.yaml'
+opts.set_defaults(cfg.CONF, DEFAULT_POLICY_FILE)
+
 
 class ConfigHook(hooks.PecanHook):
     """Attach the configuration and policy enforcer object to the request.
@@ -26,6 +36,7 @@ class ConfigHook(hooks.PecanHook):
     def __init__(self, conf):
         self.conf = conf
         self.enforcer = policy.Enforcer(conf, default_rule="default")
+        self.enforcer.register_defaults(policies.list_rules())
 
     def before(self, state):
         state.request.cfg = self.conf
@@ -35,10 +46,10 @@ class ConfigHook(hooks.PecanHook):
 class DBHook(hooks.PecanHook):
 
     def __init__(self, alarm_conn):
-        self.alarm_storage_connection = alarm_conn
+        self.storage = alarm_conn
 
     def before(self, state):
-        state.request.alarm_storage_conn = self.alarm_storage_connection
+        state.request.storage = self.storage
 
 
 class TranslationHook(hooks.PecanHook):
