@@ -20,7 +20,6 @@ from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import encodeutils
 from oslo_utils import uuidutils
-import six
 import tenacity
 import tooz.coordination
 
@@ -73,7 +72,7 @@ class HashRing(object):
         self._sorted_keys = []
 
         for node in nodes:
-            for r in six.moves.range(replicas):
+            for r in range(replicas):
                 hashed_key = self._hash('%s-%s' % (node, r))
                 self._ring[hashed_key] = node
                 self._sorted_keys.append(hashed_key)
@@ -220,10 +219,12 @@ class PartitionCoordinator(object):
         `tooz`. We then hash all the objects into buckets and return only
         the ones that hashed into *our* bucket.
         """
-        if not group_id:
+        if not group_id or not self.is_active():
             return universal_set
+
         if group_id not in self._groups:
             self.join_group(group_id)
+
         try:
             members = self._get_members(group_id)
             LOG.debug('Members of group: %s, Me: %s', members, self._my_id)
