@@ -72,15 +72,22 @@ def prepare_service(argv=None, config_files=None):
     conf = cfg.ConfigOpts()
     oslo_i18n.enable_lazy()
     log.register_options(conf)
-    log_levels = (conf.default_log_levels +
-                  ['futurist=INFO', 'keystoneclient=INFO'])
+    log_levels = (
+        conf.default_log_levels +
+        [
+            'futurist=INFO',
+            'keystoneclient=INFO',
+            'oslo_db.sqlalchemy=WARN',
+            'cotyledon=INFO'
+        ]
+    )
     log.set_defaults(default_log_levels=log_levels)
     defaults.set_cors_middleware_defaults()
     db_options.set_defaults(conf)
     if profiler_opts:
         profiler_opts.set_defaults(conf)
     policy_opts.set_defaults(conf, policy_file=os.path.abspath(
-        os.path.join(os.path.dirname(__file__), "api", "policy.json")))
+        os.path.join(os.path.dirname(__file__), "api", "policy.yaml")))
     from aodh import opts
     # Register our own Aodh options
     for group, options in opts.list_opts():
